@@ -108,6 +108,14 @@ class SubSlice:
                 self._load_data(file_path, self._vector_data[direction])
         return self._vector_data
 
+    @property
+    def vmin(self):
+        return np.min(self.data)
+
+    @property
+    def vmax(self):
+        return np.max(self.data)
+
     def clear_cache(self):
         """Remove all data from the internal cache that has been loaded so far to free memory.
         """
@@ -295,6 +303,14 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
 
         return coords
 
+    @property
+    def vmin(self):
+        return np.min(self)
+
+    @property
+    def vmax(self):
+        return np.max(self)
+
     def clear_cache(self):
         """Remove all data from the internal cache that has been loaded so far to free memory.
         """
@@ -368,6 +384,14 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
             return '3D'
         return '2D'
 
+    @implements(np.min)
+    def _min(self):
+        return min(subsclice.vmin for subsclice in self._subslices.values())
+
+    @implements(np.max)
+    def _max(self):
+        return max(subsclice.vmax for subsclice in self._subslices.values())
+
     @implements(np.mean)
     def mean(self):
         """Calculates the mean over the whole slice.
@@ -376,6 +400,17 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
         """
         return np.mean([np.mean(subsclice.data) for subsclice in self._subslices.values()])
 
+    @implements(np.std)
+    def std(self):
+        """Calculates the standard deviation over the whole slice.
+
+        :returns: The calculated standard deviation.
+        """
+        mean = self.mean
+        sum = np.sum([np.sum(np.power(subsclice.data-mean, 2)) for subsclice in self._subslices.values()])
+        N = np.sum([subsclice.data.size for subsclice in self._subslices.values()])
+        return np.sqrt(sum / N)
+
     def __array__(self):
         """Method that will be called by numpy when trying to convert the object to a numpy ndarray.
         """
@@ -425,6 +460,6 @@ class Slice(np.lib.mixins.NDArrayOperatorsMixin):
         if self.type == '3D':  # 3D-Slice
             return f"Slice([3D] cell_centered={self.cell_centered}, extent={self.extent})"
         else:  # 2D-Slice
-            return f"Slice([2D] cell_centered={self.cell_centered}, extent={self.extent}, extent_dirs={self.extent_dirs}, orientation={self.orientation}, times=[{self.times[0]:.2f})"
+            return f"Slice([2D] cell_centered={self.cell_centered}, extent={self.extent}, extent_dirs={self.extent_dirs}, orientation={self.orientation})"
 
 # __array_function__ implementations
